@@ -1,3 +1,4 @@
+import colander
 import json
 import pytest
 import mauth
@@ -5,6 +6,7 @@ from requests.exceptions import HTTPError
 
 from mauth.applications import Application, ApplicationList
 from mauth.applications.schemas import ApplicationSchema
+from mauth.core.client import APIClient
 from .base import test_api_client
 
 
@@ -41,13 +43,13 @@ class TestApplication():
 
     def test_destroy(self):
         application = Application(api_client=test_api_client)
-        application.title = 'title1'
+        application.title = 'title_destroy'
 
         new_application = application.create()
         new_application.destroy()
         app = Application(api_client=test_api_client)
-        assert not app.id
-        assert not app.title
+        with pytest.raises(colander.Invalid):
+            app.read()
 
     def test_fields_is_readable_without_any_data_passed(self):
         application = Application(api_client=test_api_client)
@@ -89,5 +91,5 @@ class TestApplicationSchema():
     def setup(self):
         self.fields = ApplicationSchema.get_fields_names()
 
-    def test_fields(self):
-        assert ApplicationSchema.__class_schema_nodes__ == self.fields
+    def test_fields_simple_output(self):
+        assert [_.name for _ in ApplicationSchema.__class_schema_nodes__] == self.fields
